@@ -331,7 +331,7 @@ void onlinehelp(int standalone,int context)
     if(standalone) {
       printtext(55, 0, HELP_HEADER, "Arrows/PgUp/PgDn/Home/End scroll, ESC exits");
     } else {
-      printtext(34, 0, HELP_HEADER, "Arrows/PgUp/PgDn/Home/End scroll, F12 toggles context, others exit");
+      printtext(34, 0, HELP_HEADER, "Arrows/PgUp/PgDn/Home/End scroll, ? toggles context, others exit");
     }
     printbg(0, 0, 1, MAX_COLUMNS);
 
@@ -348,37 +348,45 @@ void onlinehelp(int standalone,int context)
     switch(rawkey)
     {
       case KEY_LEFT:
+        if (!fnpressed) {
+    	    hview++;
+    	} else {
+    	    hview = -1;
+    	}
+        break;
+
       case KEY_UP:
-        hview++;
+        if (!fnpressed) {
+    	    hview++;
+    	} else {
+    	    hview+=PGUPDNREPEAT;
+    	}
         break;
 
       case KEY_RIGHT:
+        if (!fnpressed) {
+    	    hview--;
+    	} else {
+    	    hview = -(lastrow-MAX_ROWS+1);
+    	}
+        break;
+
       case KEY_DOWN:
-        hview--;
+        if (!fnpressed) {
+    	    hview--;
+    	} else {
+    	    hview-=PGUPDNREPEAT;
+    	}
         break;
 
-      case KEY_PGUP:
-        hview+=PGUPDNREPEAT;
-        break;
-
-      case KEY_PGDN:
-        hview-=PGUPDNREPEAT;
-        break;
-
-      case KEY_HOME:
-      hview = -1;
-      break;
-
-      case KEY_END:
-      hview = -(lastrow-MAX_ROWS+1);
-      break;
-
-      case KEY_F12:
-        context = !context;
-        hview = -1;
-        lastrow = 0;
-        continue;
-        break;
+      case KEY_COLON:
+        if (fnpressed) {
+    	    context = !context;
+    	    hview = -1;
+    	    lastrow = 0;
+    	    continue;
+    	}
+    	break;
 
     case KEY_BACKSPACE:
       if (fnpressed) {
@@ -386,9 +394,8 @@ void onlinehelp(int standalone,int context)
         break;
       }
 
-      default:
-      if (rawkey && !standalone && fnpressed) goto EXITHELP;
-
+    default:
+      if (rawkey && !standalone && !fnpressed) goto EXITHELP;
       break;
     }
 
