@@ -981,28 +981,28 @@ void generalcommands(void)
     break;
 
     case KEY_Q:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
         initsong(esnum, PLAY_BEGINNING);
 	followplay = shiftpressed;
     }
     break;
 
     case KEY_W:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
         initsong(esnum, PLAY_POS);
 	followplay = shiftpressed;
     }
     break;
 
     case KEY_E:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	initsong(esnum, PLAY_PATTERN);
 	followplay = shiftpressed;
     }
     break;
 
     case KEY_R:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	if (shiftpressed)
     	    mutechannel(epchn);
         else
@@ -1011,7 +1011,7 @@ void generalcommands(void)
     break;
 
     case KEY_T:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	if (!shiftpressed)
           editmode = EDIT_PATTERN;
 	else prevmultiplier();
@@ -1019,7 +1019,7 @@ void generalcommands(void)
     break;
 
     case KEY_Y:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	if (!shiftpressed)
           editmode = EDIT_ORDERLIST;
 	else nextmultiplier();
@@ -1027,7 +1027,7 @@ void generalcommands(void)
     break;
 
     case KEY_U:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
         if (!shiftpressed)
 	{
           if (editmode == EDIT_INSTRUMENT)
@@ -1040,7 +1040,7 @@ void generalcommands(void)
     break;
 
     case KEY_I:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
         if (!shiftpressed)
 	  editmode = EDIT_NAMES;
         else
@@ -1052,19 +1052,19 @@ void generalcommands(void)
     break;
 
     case KEY_O:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	relocator();
     }
     break;
 
     case KEY_P:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
 	load();
     }
     break;
 
     case KEY_COMMA:
-    if (!fnpressed) {
+    if (!fnpressed && (editmode != EDIT_NAMES)) {
         save();
     }
     break;
