@@ -402,62 +402,65 @@ void orderlistcommands(void)
     if (epchn == epmarkchn) epmarkchn = -1;
     break;
 
-    case KEY_INS:
-    esmarkchn = -1;
-    insertorder(0);
-    break;
-
-    case KEY_HOME:
-    if (songlen[esnum][eschn])
-    {
-      while ((eseditpos != 0) || (escolumn != 0)) orderleft();
-    }
-    break;
-
-    case KEY_END:
-    while (eseditpos != songlen[esnum][eschn]+1) orderright();
-    break;
-
-    case KEY_PGUP:
-    for (scrrep = PGUPDNREPEAT * 2; scrrep; scrrep--)
-      orderleft();
-    break;
-
-    case KEY_PGDN:
-    for (scrrep = PGUPDNREPEAT * 2; scrrep; scrrep--)
-      orderright();
-    break;
-
     case KEY_LEFT:
-    orderleft();
+    if (!fnpressed) {
+	orderleft();
+    } else {
+//HOME
+	if (songlen[esnum][eschn])
+	{
+	    while ((eseditpos != 0) || (escolumn != 0)) orderleft();
+	}
+    }
     break;
 
     case KEY_RIGHT:
-    orderright();
+    if (!fnpressed) {
+	orderright();
+    } else {
+//END
+	while (eseditpos != songlen[esnum][eschn]+1) orderright();
+    }
     break;
 
     case KEY_UP:
-    eschn--;
-    if (eschn < 0) eschn = MAX_CHN - 1;
-    if ((eseditpos == songlen[esnum][eschn]) || (eseditpos > songlen[esnum][eschn]+1))
-    {
-      eseditpos = songlen[esnum][eschn]+1;
-      escolumn = 0;
+    if (!fnpressed) {
+	eschn--;
+	if (eschn < 0) eschn = MAX_CHN - 1;
+	if ((eseditpos == songlen[esnum][eschn]) || (eseditpos > songlen[esnum][eschn]+1))
+	{
+	    eseditpos = songlen[esnum][eschn]+1;
+	    escolumn = 0;
+	}
+	if (shiftpressed) esmarkchn = -1;
+	break;
+    } else {
+//PGUP
+	for (scrrep = PGUPDNREPEAT * 2; scrrep; scrrep--)
+	    orderleft();
+	break;
     }
-    if (shiftpressed) esmarkchn = -1;
-    break;
 
     case KEY_DOWN:
-    eschn++;
-    if (eschn >= MAX_CHN) eschn = 0;
-    if ((eseditpos == songlen[esnum][eschn]) || (eseditpos > songlen[esnum][eschn]+1))
-    {
-      eseditpos = songlen[esnum][eschn]+1;
-      escolumn = 0;
+    if (!fnpressed) {
+	eschn++;
+	if (eschn >= MAX_CHN) eschn = 0;
+	if ((eseditpos == songlen[esnum][eschn]) || (eseditpos > songlen[esnum][eschn]+1))
+	{
+	    eseditpos = songlen[esnum][eschn]+1;
+	    escolumn = 0;
+	}
+	if (shiftpressed) esmarkchn = -1;
+	break;
+    } else {
+//PGDN
+        for (scrrep = PGUPDNREPEAT * 2; scrrep; scrrep--)
+	    orderright();
+        break;
     }
-    if (shiftpressed) esmarkchn = -1;
-    break;
+
   }
+
   if (eseditpos - esview < 0)
   {
     esview = eseditpos;
